@@ -44,8 +44,12 @@ try:
     import dbm.gnu
     dbm_gnu = dbm.gnu
 except ImportError:
-    import gdbm
-    dbm_gnu = gdbm
+    try:
+        import gdbm
+        dbm_gnu = gdbm
+    except ImportError:
+        import anydbm
+        dbm_gnu = anydbm
 
 try:
     from io import StringIO
@@ -96,7 +100,7 @@ class CertificateAuthority(object):
 
         # Generate certificate
         self.cert = OpenSSL.crypto.X509()
-        self.cert.set_version(3)
+        self.cert.set_version(2)
         # avoid sec_error_reused_issuer_and_serial
         self.cert.set_serial_number(random.randint(0,2**64-1))
         self.cert.get_subject().CN = 'Warcprox CA on {}'.format(socket.gethostname())[:64]
@@ -744,7 +748,7 @@ class WarcWriterThread(threading.Thread):
 
     # returns a tuple (principal_record, request_record) where principal_record is either a response or revisit record
     def build_warc_records(self, recorded_url):
-        warc_date = warctools.warc.warc_datetime_str(datetime.now())
+        warc_date = warctools.warc.warc_datetime_str(datetime.utcnow())
 
         dedup_info = None
         if self.dedup_db is not None and recorded_url.response_recorder.payload_digest is not None:
@@ -798,7 +802,7 @@ class WarcWriterThread(threading.Thread):
         refers_to_date=None):
 
         if warc_date is None:
-            warc_date = warctools.warc.warc_datetime_str(datetime.now())
+            warc_date = warctools.warc.warc_datetime_str(datetime.utcnow())
 
         record_id = warctools.WarcRecord.random_warc_uuid()
 
@@ -847,7 +851,7 @@ class WarcWriterThread(threading.Thread):
 
 
     def timestamp17(self):
-        now = datetime.now()
+        now = datetime.utcnow()
         return '{}{}'.format(now.strftime('%Y%m%d%H%M%S'), now.microsecond//1000)
 
     def _close_writer(self):
@@ -861,7 +865,7 @@ class WarcWriterThread(threading.Thread):
             self._f = None
 
     def _build_warcinfo_record(self, filename):
-        warc_record_date = warctools.warc.warc_datetime_str(datetime.now())
+        warc_record_date = warctools.warc.warc_datetime_str(datetime.utcnow())
         record_id = warctools.WarcRecord.random_warc_uuid()
 
         headers = []
